OC.L10N.register(
    "settings",
    {
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Security & setup warnings" : "Предупреждения безопасности и установки",
    "Sharing" : "Общий доступ",
    "Server-side encryption" : "Шифрование на стороне сервера",
    "External Storage" : "Внешнее хранилище",
    "Cron" : "Cron (планировщик задач)",
    "Email server" : "Почтовый сервер",
    "Log" : "Журнал",
    "Tips & tricks" : "Советы и трюки",
    "Updates" : "Обновления",
    "Couldn't remove app." : "Невозможно удалить приложение.",
    "Language changed" : "Язык изменён",
    "Invalid request" : "Неправильный запрос",
    "Authentication error" : "Ошибка аутентификации",
    "Admins can't remove themself from the admin group" : "Администратор не может удалить сам себя из группы администраторов",
    "Unable to add user to group %s" : "Невозможно добавить пользователя в группу %s",
    "Unable to remove user from group %s" : "Невозможно удалить пользователя из группы %s",
    "Couldn't update app." : "Невозможно обновить приложение",
    "Wrong password" : "Неправильный пароль",
    "No user supplied" : "Пользователь не задан",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Введите пароль восстановления администратора, в противном случае все пользовательские данные будут утеряны",
    "Wrong admin recovery password. Please check the password and try again." : "Неправильный пароль восстановления администратора. Проверьте пароль и попробуйте еще раз.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Используемый механизм не поддерживает смену паролей, но пользовательский ключ шифрования был успешно обновлён",
    "Unable to change password" : "Невозможно изменить пароль",
    "Enabled" : "Включено",
    "Not enabled" : "Не включено",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "установка и обновление приложений через магазин приложений или Объединение облачных хранилищ",
    "Federated Cloud Sharing" : "Объединение облачных хранилищ",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL использует устаревшую %s версию (%s). Пожалуйста, обновите Вашу операционную систему, иначе такие возможности, как %s не будут работать надежно.",
    "A problem occurred, please check your log files (Error: %s)" : "Возникла проблема, пожалуйста, проверьте ваши файлы журнала (Ошибка: %s)",
    "Migration Completed" : "Миграция завершена",
    "Group already exists." : "Группа уже существует.",
    "Unable to add group." : "Невозможно добавить группу.",
    "Unable to delete group." : "Невозможно удалить группу.",
    "log-level out of allowed range" : "уровень журнала вышел за разрешенный диапазон",
    "Saved" : "Сохранено",
    "test email settings" : "проверить настройки почты",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Во время отправки email произошла ошибка. Пожалуйста проверьте настройки. (Ошибка: %s)",
    "Email sent" : "Письмо отправлено",
    "You need to set your user email before being able to send test emails." : "Вы должны настроить свой e-mail пользователя прежде чем отправлять тестовые сообщения.",
    "Invalid mail address" : "Некорректный адрес email",
    "A user with that name already exists." : "Пользователь с таким именем уже существует.",
    "Unable to create user." : "Невозможно создать пользователя.",
    "Your %s account was created" : "Учетная запись %s создана",
    "Unable to delete user." : "Невозможно удалить пользователя.",
    "Forbidden" : "Запрещено",
    "Invalid user" : "Неверный пользователь",
    "Unable to change mail address" : "Невозможно изменить адрес электронной почты",
    "Email saved" : "Email сохранен",
    "Your full name has been changed." : "Ваше полное имя было изменено.",
    "Unable to change full name" : "Невозможно изменить полное имя",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Вы действительно хотите добавить домен \"{domain}\" как доверенный?",
    "Add trusted domain" : "Добавить доверенный домен",
    "Migration in progress. Please wait until the migration is finished" : "Миграция в процессе. Пожалуйста, подождите завершения миграции",
    "Migration started …" : "Начата миграция ...",
    "Sending..." : "Отправляется ...",
    "Official" : "Официальное",
    "Approved" : "Подтвержденное",
    "Experimental" : "Экспериментальное",
    "All" : "Все",
    "No apps found for your version" : "Не найдено приложений на вашу версию",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Официальные приложения разработаны силами сообщества ownCloud. Они полностью функциональны и готовы к работе.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Подтвержденные приложения разработаны доверенными разработчиками и прошли краткую проверку на наличие проблем с безопасностью. Они активно поддерживаются в открытых репозиториях и сопровождающие их разработчики подтверждают, что приложения достаточно стабильны для нормальной работы.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Это приложение не проверялось на наличие проблем с безопасностью, также оно может работать нестабильно. Устанавливайте на свой страх и риск.",
    "Update to %s" : "Обновить до %s",
    "Please wait...." : "Пожалуйста подождите...",
    "Error while disabling app" : "Ошибка при отключении приложения",
    "Disable" : "Выключить",
    "Enable" : "Включить",
    "Error while enabling app" : "Ошибка при включении приложения",
    "Updating...." : "Обновление...",
    "Error while updating app" : "Ошибка при обновлении приложения",
    "Updated" : "Обновлено",
    "Uninstalling ...." : "Удаление ...",
    "Error while uninstalling app" : "Ошибка при удалении приложения",
    "Uninstall" : "Удалить",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Приложение было включено и нуждается в обновлении. Вас перенаправит на страницу обновления через 5 секунд.",
    "App update" : "Обновить приложения",
    "No apps found for \"{query}\"" : "Не найдено приложений по вашему \"{query}\"",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Произошла ошибка. Пожалуйста загрузите сертификат PEM в ASCII кодировке.",
    "Valid until {date}" : "Действительно до {дата}",
    "Delete" : "Удалить",
    "An error occurred: {message}" : "Произошла ошибка: {message}",
    "Select a profile picture" : "Выберите аватар",
    "Very weak password" : "Очень слабый пароль",
    "Weak password" : "Слабый пароль",
    "So-so password" : "Так себе пароль",
    "Good password" : "Хороший пароль",
    "Strong password" : "Стойкий пароль",
    "Groups" : "Группы",
    "Unable to delete {objName}" : "Невозможно удалить {objName}",
    "A valid group name must be provided" : "Введите правильное имя группы",
    "deleted {groupName}" : "удалена {groupName}",
    "undo" : "отмена",
    "no group" : "без группы",
    "never" : "никогда",
    "deleted {userName}" : "удалён {userName}",
    "add group" : "добавить группу",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Изменение пароля приведёт к потере данных, так как восстановление данных не доступно для этого пользователя",
    "A valid username must be provided" : "Укажите правильное имя пользователя",
    "A valid password must be provided" : "Должен быть указан правильный пароль",
    "A valid email must be provided" : "Должен быть указан корректный адрес email",
    "__language_name__" : "Русский",
    "Personal info" : "Личная информация",
    "Sync clients" : "Синхронизация клиентов",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Все (критические проблемы, ошибки, предупреждения, информационные, отладочные)",
    "Info, warnings, errors and fatal issues" : "Информационные, предупреждения, ошибки и критические проблемы",
    "Warnings, errors and fatal issues" : "Предупреждения, ошибки и критические проблемы",
    "Errors and fatal issues" : "Ошибки и критические проблемы",
    "Fatal issues only" : "Только критические проблемы",
    "None" : "Отсутствует",
    "Login" : "Логин",
    "Plain" : "Простой",
    "NT LAN Manager" : "Менеджер NT LAN",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP был установлен неверно. Запрос getenv(\"PATH\") возвращает пустые результаты.",
    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Пожалуйста обратитесь к <a target=\"_blank\" href=\"%s\">документации по установке</a> для получения заметок по настройке php, а также к настройкам php вашего сервера, особенно это касается php-fpm.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Конфигурационный файл в режиме только для чтения. В связи с этим некоторые настройки веб-интерфейса невозможно изменить. Учтите, что для установки обновлений, вам потребуется самостоятельно разрешить запись в конфигурационный файл.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "Очевидно, PHP настроен на вычищение блоков встроенной документации. Это сделает несколько центральных приложений недоступными.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Возможно это вызвано кешем/ускорителем вроде Zend OPcache или eAccelerator.",
    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Ваш сервер работает на ОС Microsoft Windows. Мы настоятельно рекомендуем использовать ОС семейства Linux для достижения наилучших условий использования.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-модуль 'fileinfo' отсутствует. Мы настоятельно рекомендуем включить этот модуль для улучшения определения типов (mime-type) файлов.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "Блокировка файлов во время передачи отключена, это может привести к состоянию гонки. Включите параметр 'filelocking.enabled' в config.php для избежания этой проблемы. За подробной информацией обратитесь к <a target=\"_blank\" href=\"%s\">документации</a>.",
    "System locale can not be set to a one which supports UTF-8." : "Невозможно установить системную локаль, поддерживающую UTF-8",
    "This means that there might be problems with certain characters in file names." : "Это значит, что могут быть проблемы с некоторыми символами в именах файлов.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Мы рекомендуем установить требуемые пакеты для вашей системы для поддержки одного из следующих языков: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Если ваша копия ownCloud установлена не в корне домена и использует системный планировщик cron, возможны проблемы с правильной генерацией URL. Чтобы избежать этого, установите опцию \"overwrite.cli.url\" в файле config.php равной пути папки установки. (Предположительно: \"%s\".)",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Не удается запустить задачу планировщика через CLI. Произошли следующие технические ошибки:",
    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Пожалуйста, перепроверьте <a href=\"%s\">инструкцию по установке</a> и проверьте ошибки или предупреждения в <a href=\"#log-section\">журнале</a>",
    "All checks passed." : "Все проверки пройдены.",
    "Open documentation" : "Открыть документацию",
    "Allow apps to use the Share API" : "Позволить приложениям использовать API общего доступа",
    "Allow users to share via link" : "Разрешить пользователям публикации через ссылки",
    "Enforce password protection" : "Защита паролем обязательна",
    "Allow public uploads" : "Разрешить открытые/публичные загрузки",
    "Allow users to send mail notification for shared files" : "Разрешить пользователям отправлять email об открытии доступа к файлам",
    "Set default expiration date" : "Установить дату истечения по умолчанию",
    "Expire after " : "Истечение через",
    "days" : "дней",
    "Enforce expiration date" : "Срок действия обязателен",
    "Allow resharing" : "Разрешить повторное открытие общего доступа",
    "Restrict users to only share with users in their groups" : "Разрешить пользователям делиться только с членами их групп",
    "Allow users to send mail notification for shared files to other users" : "Разрешить пользователям отправлять оповещение других пользователей об открытии доступа к файлам",
    "Exclude groups from sharing" : "Исключить группы из общего доступа",
    "These groups will still be able to receive shares, but not to initiate them." : "Эти группы смогут получать общие ресурсы, но не могут их создавать.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Включить автоматическое завершение имен пользователей в окне общего доступа. Если отключено, то необходимо вводить полное имя вручную.",
    "Last cron job execution: %s." : "Последнее выполненное Cron задание: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Последнее выполненное Cron задание: %s. Что-то кажется неправильным.",
    "Cron was not executed yet!" : "Задачи cron ещё не запускались!",
    "Execute one task with each page loaded" : "Выполнять одно задание с каждой загруженной страницей",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php зарегистрирован в webcron и будет вызываться каждые 15 минут по http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Использовать системный cron для вызова cron.php каждые 15 минут.",
    "Enable server-side encryption" : "Включить шифрование на стороне сервера",
    "Please read carefully before activating server-side encryption: " : "Пожалуйста прочтите внимательно прежде чем включать шифрование на стороне сервера:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Когда вы включите шифрование, все файлы, загруженные с этого момента на сервер будут храниться в зашифрованном виде. Отключить шифрование возможно установив более позднюю дату если модуль шифрования поддерживает эту функцию, и все дополнительные условия соблюдены (например настроен ключ восстановления).",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Шифрование не гарантирует безопасность системы. Пожалуйста читайте документацию для получения информации о работе модуля шифрования и случаи его использования.",
    "Be aware that encryption always increases the file size." : "Будьте в курсе, что шифрование всегда увеличивает размер файла.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Хорошая практика делать регулярные резервные копии ваших данных. При использовании шифрования сохраняйте ключи вместе с данными.",
    "This is the final warning: Do you really want to enable encryption?" : "Это последнее предупреждение: Вы действительно желаете включить шифрование?",
    "Enable encryption" : "Включить шифрование",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Модуль шифрования не загружен, пожалуйста включите модуль шифрования в меню приложений.",
    "Select default encryption module:" : "Выберите модуль шифрования по умолчанию:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Вам необходимо произвести конвертацию ключей шифрования из старого формата (ownCloud <= 8.0) в новый. Пожалуйста включите \"Модуль шифрования по умолчанию\" и запустите команду 'occ encryption:migrate'.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Вам необходимо произвести конвертацию ключей шифрования из старого формата (ownCloud <= 8.0) в новый.",
    "Start migration" : "Запустить миграцию",
    "This is used for sending out notifications." : "Используется для отправки уведомлений.",
    "Send mode" : "Способ отправки",
    "Encryption" : "Шифрование",
    "From address" : "Адрес отправителя",
    "mail" : "почта",
    "Authentication method" : "Метод проверки подлинности",
    "Authentication required" : "Требуется аутентификация ",
    "Server address" : "Адрес сервера",
    "Port" : "Порт",
    "Credentials" : "Учётные данные",
    "SMTP Username" : "Пользователь SMTP",
    "SMTP Password" : "Пароль SMTP",
    "Store credentials" : "Сохранить учётные данные",
    "Test email settings" : "Проверить настройки почты",
    "Send email" : "Отправить email",
    "Download logfile" : "Скачать журнал",
    "More" : "Больше",
    "Less" : "Меньше",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Лог-файл - больше 100 мб. Его скачивание может занять некоторое время!",
    "What to log" : "Что записывать в журнал",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "В качестве базы данных используется SQLite. Для больших установок мы рекомендуем переключиться на другую серверную базу данных.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особенно вызывает сомнение использование SQLite при синхронизации файлов с использование клиента для ПК.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "Для перехода на другую базу данных используйте команду: 'occ db:convert-type' или ознакомьтесь с <a target=\"_blank\" href=\"%s\">документацией ↗</a>.",
    "How to do backups" : "Как сделать резервные копии",
    "Advanced monitoring" : "Расширенный мониторинг",
    "Performance tuning" : "Настройка производительности",
    "Improving the config.php" : "Улучшение config.php",
    "Theming" : "Темы оформления",
    "Hardening and security guidance" : "Руководство по безопасности и защите",
    "Version" : "Версия",
    "Developer documentation" : "Документация для разработчиков",
    "Experimental applications ahead" : "Экспериментальные приложения",
    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "Экспериментальные приложения не проверялись на наличие уязвимостей безопасности, они также могут быть нестабильны, т.к. находятся в активной разработке. Их установка может повлечь потерю информации или нарушение безопасности.",
    "by %s" : "от %s",
    "%s-licensed" : "Лицензия %s",
    "Documentation:" : "Документация:",
    "User documentation" : "Пользовательская документация",
    "Admin documentation" : "Документация для администратора",
    "Show description …" : "Показать описание ...",
    "Hide description …" : "Скрыть описание ...",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Для этого приложения не указана минимальная версия ownClowd. Будет считаться ошибкой начиная с версии ownClowd 11.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Для этого приложения не указана максимальная версия ownClowd. Будет считаться ошибкой начиная с версии ownClowd 11.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Приложение не может быть установлено, следующие зависимости не удовлетворены:",
    "Enable only for specific groups" : "Включить только для этих групп",
    "Uninstall App" : "Удалить приложение",
    "Enable experimental apps" : "Включить экспериментальные приложения",
    "SSL Root Certificates" : "Корневые сертификаты SSL",
    "Common Name" : "Общее Имя",
    "Valid until" : "Действительно до",
    "Issued By" : "Выдан",
    "Valid until %s" : "Действительно до %s",
    "Import root certificate" : "Импорт корневого сертификата",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Здравствуйте,<br><br>просто хотим сообщить, что теперь у вас есть учетная запись на %s.<br><br>Ваше имя пользователя: %s<br>Зайти: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Удачи!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Здравствуйте,\n\nПросто хотим сообщить, что теперь у вас есть учетная запись на %s.\n\nИмя пользователя: %s\nЗайти: %s\n",
    "Administrator documentation" : "Документация администратора",
    "Online documentation" : "Online-документация",
    "Forum" : "Форум",
    "Issue tracker" : "трекер проблем",
    "Commercial support" : "Коммерческая поддержка",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Вы используете <strong>%s</strong> из <strong>%s</strong>",
    "Profile picture" : "Аватар",
    "Upload new" : "Загрузить новый",
    "Select from Files" : "Выбрать из Файлов",
    "Remove image" : "Удалить аватар",
    "png or jpg, max. 20 MB" : "png или jpg, макс. 20 МБ",
    "Picture provided by original account" : "Картинка из исходной учетной записи",
    "Cancel" : "Отмена",
    "Choose as profile picture" : "Выбрать в качестве картинки профиля",
    "Full name" : "Полное имя",
    "No display name set" : "Отображаемое имя не указано",
    "Email" : "E-mail",
    "Your email address" : "Ваш адрес электронной почты",
    "For password recovery and notifications" : "Для восстановления пароля и уведомлений",
    "No email address set" : "E-mail не указан",
    "You are member of the following groups:" : "Вы являетесь членом следующих групп:",
    "Password" : "Пароль",
    "Unable to change your password" : "Невозможно сменить пароль",
    "Current password" : "Текущий пароль",
    "New password" : "Новый пароль",
    "Change password" : "Сменить пароль",
    "Language" : "Язык",
    "Help translate" : "Помочь с переводом",
    "Get the apps to sync your files" : "Получить приложения для синхронизации ваших файлов",
    "Desktop client" : "Клиент для ПК",
    "Android app" : "Android приложение",
    "iOS app" : "iOS приложение",
    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Если Вы хотите поддержать проект\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">совместная разработка</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">сообщить</a>!",
    "Show First Run Wizard again" : "Показать помощник настройки снова",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Разработано {communityopen}сообществом ownCloud{linkclose}, {githubopen}исходный код{linkclose} лицензируется в соответствии с{licenseopen}<abbr title=\"Публичной лицензией Affero General\">AGPL</abbr>{linkclose}.",
    "Show storage location" : "Показать местонахождение хранилища",
    "Show last log in" : "Показать последний вход в систему",
    "Show user backend" : "Показать пользовательскую часть",
    "Send email to new user" : "Отправлять сообщение на email новому пользователю",
    "Show email address" : "Показывать адрес email",
    "Username" : "Имя пользователя",
    "E-Mail" : "E-Mail",
    "Create" : "Создать",
    "Admin Recovery Password" : "Восстановление пароля администратора",
    "Enter the recovery password in order to recover the users files during password change" : "Введите пароль для того, чтобы восстановить файлы пользователей при смене пароля",
    "Add Group" : "Добавить группу",
    "Group" : "Группа",
    "Everyone" : "Все",
    "Admins" : "Администраторы",
    "Default Quota" : "Квота по умолчанию",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Пожалуйста, введите квоту на хранилище (например: \"512 MB\" или \"12 GB\")",
    "Unlimited" : "Неограничено",
    "Other" : "Другая",
    "Full Name" : "Полное имя",
    "Group Admin for" : "Для группы Администраторов",
    "Quota" : "Квота",
    "Storage Location" : "Место хранилища",
    "User Backend" : "Пользовательская часть",
    "Last Login" : "Последний вход",
    "change full name" : "изменить полное имя",
    "set new password" : "установить новый пароль",
    "change email address" : "изменить адрес email",
    "Default" : "По умолчанию"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
